@@ -30,7 +30,7 @@ logComment("initInstall: " + err);
 if (verifyDiskSpace(getFolder("Program"), srDest))
 {
     addFile("Diggler",
-            "diggler.jar", // jar source folder 
+            "chrome/diggler.jar", // jar source folder 
             getFolder("Chrome"),        // target folder
             "");                        // target subdir 
 
